@@ -100,8 +100,8 @@ class BaseTask(object):
         """
         self.processor = processor
 
-    def shutdown(self):
-        self.executor.shutdown()
+    # def shutdown(self):
+    #     self.executor.shutdown()
 
     def as_dict(self):
         params = {arg: getattr(self, arg) for arg in self.__dict__ if
