@@ -41,4 +41,4 @@ class PeriodicProcessor(SimpleProcessor):
             task.retries = 0
             task.exception = None
             await asyncio.sleep(task.timeout)
-        task.shutdown()
+        # task.shutdown()
